@@ -28,6 +28,7 @@
 #ifndef ROFI_DIALOG_HELPKEYS_H
 #define ROFI_DIALOG_HELPKEYS_H
 
+#include "mode.h"
 /**
  * @defgroup HELPKEYSMode KeysHelp
  * @ingroup MODES
@@ -40,5 +41,5 @@
  * #Mode object representing the help key mode view
  */
 extern Mode help_keys_mode;
-/*@}*/
+/**@}*/
 #endif // ROFI_DIALOG_HELPKEYS_H
