@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.5.1.  */
 
 /* Skeleton interface for Bison GLR parsers in C
 
-   Copyright (C) 2002-2015 Free Software Foundation, Inc.
+   Copyright (C) 2002-2015, 2018-2020 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,17 +34,18 @@
 # define YY_YY_LEXER_THEME_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
-# define YYDEBUG 1
+# define YYDEBUG 0
 #endif
 #if YYDEBUG
 extern int yydebug;
 #endif
 /* "%code requires" blocks.  */
-#line 35 "../lexer/theme-parser.y" /* glr.c:197  */
+#line 34 "../lexer/theme-parser.y"
 
 #include "theme.h"
 #include "xrmoptions.h"
 #include "css-colors.h"
+#include "rofi.h"
 
 typedef struct YYLTYPE {
   int first_line;
@@ -75,7 +76,7 @@ typedef struct YYLTYPE {
         }                                                              \
     while (0)
 
-#line 79 "lexer/theme-parser.h" /* glr.c:197  */
+#line 80 "lexer/theme-parser.h"
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -93,73 +94,104 @@ typedef struct YYLTYPE {
     T_INT = 258,
     T_DOUBLE = 259,
     T_STRING = 260,
-    T_PROP_NAME = 261,
-    T_COLOR_NAME = 262,
-    T_NAME_ELEMENT = 263,
-    T_BOOLEAN = 264,
-    T_COLOR = 265,
-    T_LINK = 266,
-    T_ELEMENT = 267,
-    T_POS_CENTER = 268,
-    T_POS_EAST = 269,
-    T_POS_WEST = 270,
-    T_POS_NORTH = 271,
-    T_POS_SOUTH = 272,
-    T_NONE = 273,
-    T_BOLD = 274,
-    T_ITALIC = 275,
-    T_UNDERLINE = 276,
-    T_STRIKETHROUGH = 277,
-    T_SMALLCAPS = 278,
-    T_DASH = 279,
-    T_SOLID = 280,
-    T_UNIT_PX = 281,
-    T_UNIT_EM = 282,
-    T_UNIT_CH = 283,
-    T_UNIT_PERCENT = 284,
-    T_ANGLE_DEG = 285,
-    T_ANGLE_GRAD = 286,
-    T_ANGLE_RAD = 287,
-    T_ANGLE_TURN = 288,
-    ORIENTATION_HORI = 289,
-    ORIENTATION_VERT = 290,
-    T_COL_RGBA = 291,
-    T_COL_HSL = 292,
-    T_COL_HWB = 293,
-    T_COL_CMYK = 294,
-    T_PARENT_LEFT = 295,
-    T_PARENT_RIGHT = 296,
-    T_COMMA = 297,
-    T_OPTIONAL_COMMA = 298,
-    T_FORWARD_SLASH = 299,
-    T_PERCENT = 300,
-    T_LIST_OPEN = 301,
-    T_LIST_CLOSE = 302,
-    T_BOPEN = 303,
-    T_BCLOSE = 304,
-    T_PSEP = 305,
-    T_PCLOSE = 306,
-    T_NSEP = 307,
-    T_SSEP = 308,
-    T_NAME_PREFIX = 309,
-    T_WHITESPACE = 310,
-    T_PDEFAULTS = 311,
-    T_CONFIGURATION = 312,
-    T_COLOR_TRANSPARENT = 313,
-    T_INHERIT = 314
+    T_CHAR = 261,
+    T_PROP_NAME = 262,
+    T_COLOR_NAME = 263,
+    T_NAME_ELEMENT = 264,
+    T_BOOLEAN = 265,
+    T_COLOR = 266,
+    T_LINK = 267,
+    T_ELEMENT = 268,
+    T_POS_CENTER = 269,
+    T_POS_EAST = 270,
+    T_POS_WEST = 271,
+    T_POS_NORTH = 272,
+    T_POS_SOUTH = 273,
+    T_MEDIA = 274,
+    T_NONE = 275,
+    T_BOLD = 276,
+    T_ITALIC = 277,
+    T_UNDERLINE = 278,
+    T_STRIKETHROUGH = 279,
+    T_SMALLCAPS = 280,
+    T_DASH = 281,
+    T_SOLID = 282,
+    T_UNIT_PX = 283,
+    T_UNIT_MM = 284,
+    T_UNIT_EM = 285,
+    T_UNIT_CH = 286,
+    T_UNIT_PERCENT = 287,
+    T_ANGLE_DEG = 288,
+    T_ANGLE_GRAD = 289,
+    T_ANGLE_RAD = 290,
+    T_ANGLE_TURN = 291,
+    ORIENTATION_HORI = 292,
+    ORIENTATION_VERT = 293,
+    CURSOR_DEF = 294,
+    CURSOR_PTR = 295,
+    CURSOR_TXT = 296,
+    T_COL_RGBA = 297,
+    T_COL_HSL = 298,
+    T_COL_HWB = 299,
+    T_COL_CMYK = 300,
+    T_URL = 301,
+    T_WIDTH = 302,
+    T_HEIGHT = 303,
+    T_BOTH = 304,
+    T_TO = 305,
+    T_LEFT = 306,
+    T_RIGHT = 307,
+    T_TOP = 308,
+    T_BOTTOM = 309,
+    T_LINEAR_GRADIENT = 310,
+    T_PARENT_LEFT = 311,
+    T_PARENT_RIGHT = 312,
+    T_COMMA = 313,
+    T_OPTIONAL_COMMA = 314,
+    T_FORWARD_SLASH = 315,
+    T_PERCENT = 316,
+    T_LIST_OPEN = 317,
+    T_LIST_CLOSE = 318,
+    T_MODIFIER_ADD = 319,
+    T_MODIFIER_SUBTRACT = 320,
+    T_MODIFIER_MULTIPLY = 321,
+    T_MODIFIER_MAX = 322,
+    T_MODIFIER_MIN = 323,
+    T_CALC = 324,
+    T_BOPEN = 325,
+    T_BCLOSE = 326,
+    T_PSEP = 327,
+    T_PCLOSE = 328,
+    T_NSEP = 329,
+    T_SSEP = 330,
+    T_NAME_PREFIX = 331,
+    T_WHITESPACE = 332,
+    T_PDEFAULTS = 333,
+    T_CONFIGURATION = 334,
+    T_RESET_THEME = 335,
+    T_COLOR_TRANSPARENT = 336,
+    T_INHERIT = 337,
+    T_MEDIA_WIDTH = 338,
+    T_MEDIA_HEIGHT = 339,
+    T_MEDIA_MIN = 340,
+    T_MEDIA_MONITOR_ID = 341,
+    T_MEDIA_MAX = 342,
+    T_MEDIA_SEP = 343,
+    T_VAR_START = 344,
+    T_ENV_START = 345
   };
 #endif
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 137 "../lexer/theme-parser.y" /* glr.c:197  */
+#line 139 "../lexer/theme-parser.y"
 
-	int           ival;
-	double        fval;
+    int           ival;
+    double        fval;
     char          *sval;
+    char          cval;
     int           bval;
     WindowLocation wloc;
     ThemeColor    colorval;
@@ -168,10 +200,11 @@ union YYSTYPE
     Property      *property;
     GHashTable    *property_list;
     RofiDistance      distance;
+    RofiDistanceUnit  *distance_unit;
+
+#line 206 "lexer/theme-parser.h"
 
-#line 173 "lexer/theme-parser.h" /* glr.c:197  */
 };
-
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
