@@ -31,16 +31,6 @@
 typedef struct _NkBindings NkBindings;
 typedef struct _NkBindingsSeat NkBindingsSeat;
 
-typedef enum {
-    NK_BINDINGS_MODIFIER_SHIFT,
-    NK_BINDINGS_MODIFIER_CONTROL,
-    NK_BINDINGS_MODIFIER_ALT,
-    NK_BINDINGS_MODIFIER_SUPER,
-    NK_BINDINGS_MODIFIER_META,
-    NK_BINDINGS_MODIFIER_HYPER,
-#define NK_BINDINGS_NUM_MODIFIERS 6
-} NkBindingsModifiers;
-
 typedef enum {
     NK_BINDINGS_KEY_STATE_PRESS,
     NK_BINDINGS_KEY_STATE_PRESSED,
@@ -52,8 +42,6 @@ typedef enum {
     NK_BINDINGS_BUTTON_STATE_RELEASE,
 } NkBindingsButtonState;
 
-#define NK_BINDINGS_MODIFIER_MASK(m) (1 << (m))
-
 typedef enum {
     NK_BINDINGS_MOUSE_BUTTON_PRIMARY,
     NK_BINDINGS_MOUSE_BUTTON_SECONDARY,
@@ -66,12 +54,12 @@ typedef enum {
 typedef enum {
     NK_BINDINGS_SCROLL_AXIS_VERTICAL,
     NK_BINDINGS_SCROLL_AXIS_HORIZONTAL,
-#define NK_BINDINGS_SCROLL_NUM_AXIS 2
 } NkBindingsScrollAxis;
+#define NK_BINDINGS_SCROLL_NUM_AXIS 2
 
 typedef enum {
     NK_BINDINGS_ERROR_SYNTAX,
-    NK_BINDINGS_ERROR_NOTHING,
+    NK_BINDINGS_ERROR_UNKNOWN_KEYSYM,
     NK_BINDINGS_ERROR_ALREADY_REGISTERED,
 } NkBindingsError;
 #define NK_BINDINGS_ERROR (nk_bindings_error())
@@ -80,8 +68,11 @@ GQuark nk_bindings_error(void);
 NkBindings *nk_bindings_new(guint64 double_click_delay);
 void nk_bindings_free(NkBindings *bindings);
 
-typedef gboolean (*NkBindingsCallback)(guint64 scope, gpointer target, gpointer user_data);
-gboolean nk_bindings_add_binding(NkBindings *bindings, guint64 scope, const gchar *string, NkBindingsCallback callback, gpointer user_data, GDestroyNotify notify, GError **error);
+#define NK_BINDINGS_BINDING_TRIGGERED TRUE
+#define NK_BINDINGS_BINDING_NOT_TRIGGERED FALSE
+typedef gboolean (*NkBindingsCheckCallback)(guint64 scope, gpointer target, gpointer user_data);
+typedef void (*NkBindingsTriggerCallback)(guint64 scope, gpointer target, gpointer user_data);
+gboolean nk_bindings_add_binding(NkBindings *bindings, guint64 scope, const gchar *string, NkBindingsCheckCallback check_callback, NkBindingsTriggerCallback trigger_callback, gpointer user_data, GDestroyNotify notify, GError **error);
 void nk_bindings_reset_bindings(NkBindings *bindings);
 
 NkBindingsSeat *nk_bindings_seat_new(NkBindings *bindings, enum xkb_context_flags flags);
@@ -91,7 +82,7 @@ void nk_bindings_seat_update_keymap(NkBindingsSeat *seat, struct xkb_keymap *key
 struct xkb_context *nk_bindings_seat_get_context(NkBindingsSeat *seat);
 
 gchar *nk_bindings_seat_handle_key(NkBindingsSeat *seat, gpointer target, xkb_keycode_t key, NkBindingsKeyState state);
-gchar *nk_bindings_seat_handle_key_with_modmask(NkBindingsSeat *self, gpointer target, xkb_mod_mask_t modmask, xkb_keycode_t keycode, NkBindingsKeyState state);
+gchar *nk_bindings_seat_handle_key_with_modmask(NkBindingsSeat *seat, gpointer target, xkb_mod_mask_t modmask, xkb_keycode_t key, NkBindingsKeyState state);
 gboolean nk_bindings_seat_handle_button(NkBindingsSeat *seat, gpointer target, NkBindingsMouseButton button, NkBindingsButtonState state, guint64 timestamp);
 gboolean nk_bindings_seat_handle_scroll(NkBindingsSeat *seat, gpointer target, NkBindingsScrollAxis axis, gint32 steps);
 void nk_bindings_seat_update_mask(NkBindingsSeat *seat, gpointer target, xkb_mod_mask_t depressed_mods, xkb_mod_mask_t latched_mods, xkb_mod_mask_t locked_mods, xkb_layout_index_t depressed_layout, xkb_layout_index_t latched_layout, xkb_layout_index_t locked_layout);
