@@ -1,5 +1,5 @@
 /*
- * libnkutils/token - Miscellaneous utilities, token module
+ * libnkutils/bindings - Miscellaneous utilities, bindings module
  *
  * Copyright © 2011-2017 Quentin "Sardem FF7" Glidic
  *
@@ -46,16 +46,19 @@ typedef struct {
 } NkBindingsTestFixture;
 
 typedef struct {
+    guint64 scope;
     const gchar *binding;
     guint64 trigger;
 } NkBindingsTestBinding;
 
 typedef struct {
     NkBindingsTestFixture *fixture;
+    guint64 scope;
     guint64 trigger;
 } NkBindingsTestBindingSlice;
 
 typedef struct {
+    guint64 scope;
     xkb_keycode_t key;
     NkBindingsKeyState state;
     gboolean fail;
@@ -412,17 +415,33 @@ static const struct {
     },
 #ifdef NK_XKBCOMMON_HAS_COMPOSE
     {
-        .testpath = "/nkutils/bindings/compose/with-binding",
+        .testpath = "/nkutils/bindings/compose/with-binding/start",
         .data = {
             .bindings = {
                 { .binding = "dead_grave", .trigger = 1 },
                 { .binding = NULL }
             },
+            .keys = {
+                { .key = KEYCODE_TILDE, .triggered = 1 },
+                { .key = KEYCODE_TILDE, .state = NK_BINDINGS_KEY_STATE_RELEASE },
+                { .key = KEYCODE_TILDE, .triggered = 1 },
+                { .key = KEYCODE_TILDE, .state = NK_BINDINGS_KEY_STATE_RELEASE },
+                { .key = KEYCODE_NONE }
+            },
+        }
+    },
+    {
+        .testpath = "/nkutils/bindings/compose/with-binding/middle",
+        .data = {
+            .bindings = {
+                { .binding = "space", .trigger = 1 },
+                { .binding = NULL }
+            },
             .keys = {
                 { .key = KEYCODE_TILDE },
                 { .key = KEYCODE_TILDE, .state = NK_BINDINGS_KEY_STATE_RELEASE },
-                { .key = KEYCODE_TILDE, .text = "`" },
-                { .key = KEYCODE_TILDE, .state = NK_BINDINGS_KEY_STATE_RELEASE },
+                { .key = KEYCODE_SPACE, .text = "`" },
+                { .key = KEYCODE_SPACE, .state = NK_BINDINGS_KEY_STATE_RELEASE },
                 { .key = KEYCODE_NONE }
             },
         }
@@ -461,14 +480,25 @@ _nk_bindings_tests_setup(NkBindingsTestFixture *fixture, G_GNUC_UNUSED gconstpoi
 }
 
 static gboolean
-_nk_bindings_tests_callback(guint64 scope, gpointer target, gpointer user_data)
+_nk_bindings_tests_check_callback(guint64 scope, gpointer target, gpointer user_data)
 {
     NkBindingsTestBindingSlice *slice = user_data;
-    g_assert_cmpuint(scope, ==, 0);
+    g_assert_null(target);
+
+    if ( slice->scope != scope )
+        return NK_BINDINGS_BINDING_NOT_TRIGGERED;
+
+    return NK_BINDINGS_BINDING_TRIGGERED;
+}
+
+static void
+_nk_bindings_tests_trigger_callback(guint64 scope, gpointer target, gpointer user_data)
+{
+    NkBindingsTestBindingSlice *slice = user_data;
+    g_assert_cmpuint(scope, ==, slice->scope);
     g_assert_null(target);
 
     slice->fixture->triggered = slice->trigger;
-    return TRUE;
 }
 
 static void
@@ -484,8 +514,9 @@ _nk_bindings_tests_func(NkBindingsTestFixture *fixture, gconstpointer user_data)
         gboolean ret;
 
         slice->fixture = fixture;
+        slice->scope = binding->scope;
         slice->trigger = binding->trigger;
-        ret = nk_bindings_add_binding(fixture->bindings, 0, binding->binding, _nk_bindings_tests_callback, slice++, NULL, &error);
+        ret = nk_bindings_add_binding(fixture->bindings, binding->scope, binding->binding, _nk_bindings_tests_check_callback, _nk_bindings_tests_trigger_callback, slice++, NULL, &error);
 
         g_assert_true(ret);
         g_assert_no_error(error);
@@ -533,10 +564,13 @@ int
 main(int argc, char *argv[])
 {
     setlocale(LC_CTYPE, "en_US.UTF-8");
+
     g_test_init(&argc, &argv, NULL);
 
     g_test_set_nonfatal_assertions();
 
+    g_setenv("HOME", "/var/empty", TRUE);
+
     gsize i;
     for ( i = 0 ; i < G_N_ELEMENTS(_nk_bindings_tests_list) ; ++i )
         g_test_add(_nk_bindings_tests_list[i].testpath, NkBindingsTestFixture, &_nk_bindings_tests_list[i].data, _nk_bindings_tests_setup, _nk_bindings_tests_func, _nk_bindings_tests_teardown);
