@@ -32,11 +32,14 @@
 #include <helper.h>
 #include <string.h>
 #include <xcb/xcb_ewmh.h>
+#include "theme.h"
 #include "display.h"
 #include "xcb.h"
 #include "xcb-internal.h"
 #include "rofi.h"
 #include "settings.h"
+#include "widgets/textbox.h"
+#include "rofi-icon-fetcher.h"
 
 static int       test = 0;
 
@@ -47,11 +50,45 @@ static int       test = 0;
 #define TASSERTE( a, b )    {                                                            \
         if ( ( a ) == ( b ) ) {                                                          \
             printf ( "Test %i passed (%s == %s) (%u == %u)\n", ++test, # a, # b, a, b ); \
-        }else {                                                                          \
+        } else {                                                                         \
             printf ( "Test %i failed (%s == %s) (%u != %u)\n", ++test, # a, # b, a, b ); \
             abort ( );                                                                   \
         }                                                                                \
 }
+ThemeWidget *rofi_theme = NULL;
+void rofi_clear_error_messages ( void ) {}
+uint32_t rofi_icon_fetcher_query ( const char *name, const int size )
+{
+  return 0;
+}
+uint32_t rofi_icon_fetcher_query_advanced ( const char *name, const int wsize, const int hsize )
+{
+  return 0;
+}
+
+cairo_surface_t * rofi_icon_fetcher_get ( const uint32_t uid )
+{
+  return NULL;
+}
+
+double textbox_get_estimated_char_height ( void )
+{
+  return 12.0;
+}
+void rofi_view_get_current_monitor ( int *width, int *height )
+{
+*width = 1920;
+*height = 1080;
+}
+double textbox_get_estimated_ch ( void )
+{
+  return 9.0;
+}
+gboolean rofi_theme_parse_string ( const char *string )
+{
+return 0;
+}
+
 void rofi_add_error_message ( G_GNUC_UNUSED GString *msg )
 {
 }
@@ -71,7 +108,7 @@ void display_startup_notification ( G_GNUC_UNUSED RofiHelperExecuteContext *cont
 {
 }
 
-int main ( int argc, char ** argv )
+int main ( int argc, char **argv )
 {
     cmd_set_arguments ( argc, argv );
 
